Project currently a placeholder pending an unconfirmed migration, please contact @arm64e (kritanta) regarding the pypi package. 


<h1 align="center">Theos</h1>
<p align="center"><strong>A cross-platform build system for creating iOS, macOS, Linux, and Windows programs.</strong></p>
<p align="center">
<a href="https://theos.dev/">Home</a> –
<a href="https://github.com/theos/theos/wiki">Documentation</a> –
<a href="https://github.com/theos/theos/releases">Changelogs</a> –
<a href="https://github.com/theos/theos/wiki/Help">Get Help</a> –
<a href="https://twitter.com/theosdev">@theosdev</a> –
<a href="https://iphonedevwiki.net/index.php/How_to_use_IRC">IRC</a>
</p>

## Contributors
<table>
<tr>
<td align="center"><a href="https://github.com/kirb"><img src="https://github.com/kirb.png" width="100" alt=""><br>kirb</a></td>
<td align="center"><a href="https://github.com/uroboro"><img src="https://github.com/uroboro.png" width="100" alt=""><br>uroboro</a></td>
<td align="center"><a href="https://github.com/kabiroberai"><img src="https://github.com/kabiroberai.png" width="100" alt=""><br>kabiroberai</a></td>
<td align="center"><a href="https://github.com/DHowett"><img src="https://github.com/DHowett.png" width="100" alt=""><br>DHowett</a></td>
<td align="center"><a href="https://github.com/rpetrich"><img src="https://github.com/rpetrich.png" width="100" alt=""><br>rpetrich</a></td>
</tr>
</table>

Thanks to the following people for contributing to Theos in the past:
[angelXwind](https://github.com/angelXwind),
[eswick](https://github.com/eswick),
[coolstar](https://github.com/coolstar),
[DuIslingr](https://github.com/DuIslingr),
[vsnrain](https://github.com/vsnrain),
[r-plus](https://github.com/r-plus),
[sbingner](https://github.com/sbingner),
[andrewwiik](https://github.com/andrewwiik),
[conradev](https://github.com/conradev),
[DGh0st](https://github.com/DGh0st),
[lechium](https://github.com/lechium),
[mstg](https://github.com/mstg),
[kemmis](https://github.com/kemmis),
[liuxuan30](https://github.com/liuxuan30),
[nin9tyfour](https://github.com/nin9tyfour),
[supermamon](https://github.com/supermamon),
[theiostream](https://github.com/theiostream),
[Stilldabomb](https://github.com/Stilldabomb),
[NSExceptional](https://github.com/NSExceptional)

## License
See [LICENSE.md](LICENSE.md) for licensing information.
